@@ -15,7 +15,7 @@
 #' associated with the token have already been baked in to the token itself and
 #' gargle does not support incremental authorization. The main point of
 #' `credentials_byo_oauth2()` is to allow `token_fetch()` (and packages that
-#' wrap it) to accomodate a "bring your own token" workflow.
+#' wrap it) to accommodate a "bring your own token" workflow.
 #'
 #' This also makes it possible to obtain a token with one package and then
 #' register it for use with another package. For example, the default scope
@@ -42,14 +42,14 @@
 #' credentials_byo_oauth2(token = my_token)
 #' }
 credentials_byo_oauth2 <- function(scopes = NULL, token, ...) {
-  cat_line("trying credentials_byo_oauth()")
+  ui_line("trying credentials_byo_oauth()")
   if (inherits(token, "request")) {
     token <- token$auth_token
   }
   stopifnot(inherits(token, "Token2.0"))
 
   if (!is.null(scopes)) {
-    cat_line(
+    ui_line(
       "`scopes` cannot be specified when user brings their own OAuth token; ",
       "`scopes` are already implicit in the token"
     )
